@@ -6,7 +6,7 @@ use warnings;
 
 
 our $AUTHORITY = 'cpan:KJETILK';
-our $VERSION   = '0.002';
+our $VERSION   = '0.006';
 
 use Moo;
 use Type::Tiny::Role;
@@ -14,7 +14,7 @@ use Types::URI -all;
 use Types::Standard qw(InstanceOf);
 use Attean;
 use Attean::RDF;
-use AtteanX::Store::SPARQL::Plan::BGP;
+use AtteanX::Plan::SPARQLBGP;
 use LWP::UserAgent;
 
 use Data::Dumper;
@@ -87,7 +87,7 @@ sub plans_for_algebra {
 															 graph => $active_graphs,
 															 distinct => 0));
 			  }
-		return AtteanX::Store::SPARQL::Plan::BGP->new(children => \@quads,
+		return AtteanX::Plan::SPARQLBGP->new(children => \@quads,
 																	 distinct => 0); # TODO: Fix
 	}
 	return;
@@ -123,7 +123,7 @@ endpoints.
 
 This distribution also brings a corresponding
 L<AtteanX::Model::SPARQL>, which allows query plans to be made, and a
-L<AtteanX::Store::SPARQL::Plan::BGP> plan class, which contains a
+L<AtteanX::Plan::SPARQLBGP> plan class, which contains a
 rudimentary cost estimate that attempts to avoid sending Cartesian
 joins to remote endpoints if possible.
 
@@ -177,7 +177,7 @@ Kjetil Kjernsmo E<lt>kjetilk@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2015 by Kjetil Kjernsmo and Gregory
+This software is copyright (c) 2015, 2016 by Kjetil Kjernsmo and Gregory
 Todd Williams.
 
 This is free software; you can redistribute it and/or modify it under
